Trait AlgorithmName
trait AlgorithmName
Trait which stores algorithm name constant, used in Debug implementations.
Required Methods
fn write_alg_name(f: &mut Formatter<'_>) -> ResultWrite algorithm name into
f.
AlgorithmNametrait AlgorithmName
Trait which stores algorithm name constant, used in Debug implementations.
fn write_alg_name(f: &mut Formatter<'_>) -> ResultWrite algorithm name into f.