Trait KeyIvInit
trait KeyIvInit: KeySizeUser + IvSizeUser + Sized
Types which can be initialized from key and initialization vector (nonce).
Required Methods
fn new(key: &Key<Self>, iv: &Iv<Self>) -> SelfCreate new value from fixed length key and nonce.
Provided Methods
fn new_from_slices(key: &[u8], iv: &[u8]) -> Result<Self, InvalidLength>Create new value from variable length key and nonce.
Implementors
impl<T> KeyIvInit for T